==> kubernetes-model-admissionregistration-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/authentication/v1alpha1/SelfSubjectReviewStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authentication.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.authentication.UserInfo;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.authentication.UserInfoBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.authentication.UserInfoFluentImpl;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SelfSubjectReviewStatusFluentImpl<A extends SelfSubjectReviewStatusFluent<A>> extends BaseFluent<A> implements SelfSubjectReviewStatusFluent<A>{
  public SelfSubjectReviewStatusFluentImpl() {
  }
  public SelfSubjectReviewStatusFluentImpl(SelfSubjectReviewStatus instance) {
    this.withUserInfo(instance.getUserInfo()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private UserInfoBuilder userInfo;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildUserInfo instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserInfo getUserInfo() {
    return this.userInfo!=null ?this.userInfo.build():null;
  }
  public UserInfo buildUserInfo() {
    return this.userInfo!=null ?this.userInfo.build():null;
  }
  public A withUserInfo(UserInfo userInfo) {
    _visitables.get("userInfo").remove(this.userInfo);
    if (userInfo!=null){ this.userInfo= new UserInfoBuilder(userInfo); _visitables.get("userInfo").add(this.userInfo);} else { this.userInfo = null; _visitables.get("userInfo").remove(this.userInfo); } return (A) this;
  }
  public Boolean hasUserInfo() {
    return this.userInfo != null;
  }
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> withNewUserInfo() {
    return new SelfSubjectReviewStatusFluentImpl.UserInfoNestedImpl();
  }
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> withNewUserInfoLike(UserInfo item) {
    return new SelfSubjectReviewStatusFluentImpl.UserInfoNestedImpl(item);
  }
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> editUserInfo() {
    return withNewUserInfoLike(getUserInfo());
  }
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> editOrNewUserInfo() {
    return withNewUserInfoLike(getUserInfo() != null ? getUserInfo(): new UserInfoBuilder().build());
  }
  public SelfSubjectReviewStatusFluent.UserInfoNested<A> editOrNewUserInfoLike(UserInfo item) {
    return withNewUserInfoLike(getUserInfo() != null ? getUserInfo(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SelfSubjectReviewStatusFluentImpl that = (SelfSubjectReviewStatusFluentImpl) o;
    if (userInfo != null ? !userInfo.equals(that.userInfo) :that.userInfo != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(userInfo,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (userInfo != null) { sb.append("userInfo:"); sb.append(userInfo + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class UserInfoNestedImpl<N> extends UserInfoFluentImpl<SelfSubjectReviewStatusFluent.UserInfoNested<N>> implements SelfSubjectReviewStatusFluent.UserInfoNested<N>,Nested<N>{
    UserInfoNestedImpl(UserInfo item) {
      this.builder = new UserInfoBuilder(this, item);
    }
    UserInfoNestedImpl() {
      this.builder = new UserInfoBuilder(this);
    }
    UserInfoBuilder builder;
    public N and() {
      return (N) SelfSubjectReviewStatusFluentImpl.this.withUserInfo(builder.build());
    }
    public N endUserInfo() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/authentication/v1alpha1/SelfSubjectReviewStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authentication.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.authentication.UserInfo;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.authentication.UserInfoBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.authentication.UserInfoFluentImpl;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SelfSubjectReviewStatusFluentImpl<A extends SelfSubjectReviewStatusFluent<A>> extends BaseFluent<A> implements SelfSubjectReviewStatusFluent<A>{
  public SelfSubjectReviewStatusFluentImpl() {
  }
  public SelfSubjectReviewStatusFluentImpl(SelfSubjectReviewStatus instance) {
    if (instance != null) {
      this.withUserInfo(instance.getUserInfo());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private UserInfoBuilder userInfo;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildUserInfo instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserInfo getUserInfo() {
    return this.userInfo!=null ?this.userInfo.build():null;
  }
  public UserInfo buildUserInfo() {
    return this.userInfo!=null ?this.userInfo.build():null;
  }
  public A withUserInfo(UserInfo userInfo) {
    _visitables.get("userInfo").remove(this.userInfo);
    if (userInfo!=null){ this.userInfo= new UserInfoBuilder(userInfo); _visitables.get("userInfo").add(this.userInfo);} else { this.userInfo = null; _visitables.get("userInfo").remove(this.userInfo); } return (A) this;
  }
  public Boolean hasUserInfo() {
    return this.userInfo != null;
  }
  public SelfSubjectReviewStatusFluentImpl.UserInfoNested<A> withNewUserInfo() {
    return new SelfSubjectReviewStatusFluentImpl.UserInfoNestedImpl();
  }
  public SelfSubjectReviewStatusFluentImpl.UserInfoNested<A> withNewUserInfoLike(UserInfo item) {
    return new SelfSubjectReviewStatusFluentImpl.UserInfoNestedImpl(item);
  }
  public SelfSubjectReviewStatusFluentImpl.UserInfoNested<A> editUserInfo() {
    return withNewUserInfoLike(getUserInfo());
  }
  public SelfSubjectReviewStatusFluentImpl.UserInfoNested<A> editOrNewUserInfo() {
    return withNewUserInfoLike(getUserInfo() != null ? getUserInfo(): new UserInfoBuilder().build());
  }
  public SelfSubjectReviewStatusFluentImpl.UserInfoNested<A> editOrNewUserInfoLike(UserInfo item) {
    return withNewUserInfoLike(getUserInfo() != null ? getUserInfo(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SelfSubjectReviewStatusFluentImpl that = (SelfSubjectReviewStatusFluentImpl) o;
    if (!java.util.Objects.equals(userInfo, that.userInfo)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(userInfo,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (userInfo != null) { sb.append("userInfo:"); sb.append(userInfo + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class UserInfoNestedImpl<N> extends UserInfoFluentImpl<SelfSubjectReviewStatusFluentImpl.UserInfoNested<N>> implements SelfSubjectReviewStatusFluentImpl.UserInfoNested<N>,Nested<N>{
    UserInfoNestedImpl(UserInfo item) {
      this.builder = new UserInfoBuilder(this, item);
    }
    UserInfoNestedImpl() {
      this.builder = new UserInfoBuilder(this);
    }
    UserInfoBuilder builder;
    public N and() {
      return (N) SelfSubjectReviewStatusFluentImpl.this.withUserInfo(builder.build());
    }
    public N endUserInfo() {
      return and();
    }
    
  }
  
}
